@@ -635,6 +635,9 @@ class Tunnel(ChunkParser):
   def _BackEnd(server, backends, require_all, conns):
     """This is the back-end end of a tunnel."""
     self = Tunnel(conns)
+    if conns and not conns.config.isfrontend:
+        self.ExtendSSLRetryDelays()
+
     self.backends = backends
     self.require_all = require_all
     self.server_info[self.S_NAME] = server
